@@ -1,12 +1,12 @@
 package Perinci::Object::Metadata;
 
-our $DATE = '2014-11-07'; # DATE
-our $VERSION = '0.19'; # VERSION
+our $DATE = '2014-12-10'; # DATE
+our $VERSION = '0.20'; # VERSION
 
 use 5.010;
 use strict;
 use warnings;
-use SHARYANTO::String::Util qw(trim_blank_lines);
+use String::Trim::More qw(trim_blank_lines);
 
 sub new {
     my ($class, $meta) = @_;
@@ -139,7 +139,7 @@ Perinci::Object::Metadata - Base class for Perinci::Object metadata classes
 
 =head1 VERSION
 
-This document describes version 0.19 of Perinci::Object::Metadata (from Perl distribution Perinci-Object), released on 2014-11-07.
+This document describes version 0.20 of Perinci::Object::Metadata (from Perl distribution Perinci-Object), released on 2014-12-10.
 
 =head1 METHODS
 
